import React from 'react'
import { Provider } from 'react-redux'
import BasicLayout from './layouts/BasicLayout'
import UserLayout from './layouts/UserLayout'
import { Router, HashRouter, Route, hashHistory, Switch, Redirect } from 'react-router-dom'
import { getRouterData } from './common/router'
import { pushStore } from './common/menu'
import axios from './utils/request'
import _ from 'lodash'
import createHistory from 'history/createBrowserHistory'
const history = createHistory()
const location = history.location

export default class RootComponent extends React.Component {
    state = { store: this.props.store, globalEventDistributor: this.props.globalEventDistributor };

    componentDidCatch(error, info) {
      console.log(error, info)
    }
    setStore(store) {
      this.setState({ ...this.state, store: store })
    }

    setGlobalEventDistributor(globalEventDistributor) {
      this.setState({ ...this.state, globalEventDistributor: globalEventDistributor })
    }

    componentWillMount() {
      let previousPath = this.props.history.location.pathname
      this.props.history.listen((location, action) => {
        console.log('网址改变了,我这里已经知道')
        if (previousPath === location.pathname) return
        console.log('前后网址不一样,准备跳转')
        console.log(location, action)
        if (action === 'PUSH') { this.props.globalEventDistributor.dispatch({ type: 'to', path: location.pathname, owner: 'base' }) }
      })
    }

    render() {
      let ret = <div></div>
      const routerData = getRouterData()
      let customProps = { routerData: routerData, globalEventDistributor: this.state.globalEventDistributor }
      let store = this.state.globalEventDistributor.getState()
      let menu = []
      Object.keys(store).forEach((name) => {
        if (store[name].menu) {
          if (_.isArray(store[name].menu)) {
            store[name].menu.forEach((item) => {
              pushStore(item)
            })
          } else {
            pushStore(store[name].menu)
          }
        }
      })

      if (this.state.store && this.state.globalEventDistributor) {
        ret = <Provider store={this.state.store}>
          <Router history={this.props.history}>
            <Switch>
              <Route path='/user' render={props => <UserLayout {...customProps} {...props} />} />
              <Route path='/' render={props => <BasicLayout {...customProps} {...props} />} />
            </Switch>
          </Router>

        </Provider>
      }
      return ret
    }
}
